pragma Singleton

import QtQuick 2.9

QtObject {
    property QtObject colors: QtObject {

        property color highlightBlue: "#23A0E9"
        property color hoverBlue: "#E5F3FF"
        property color hoverBorder: "#CCE8FF"
        property color borderGray: "#D6D6D6"
        property color background: "#DFDFDF"
        property color darkBackground: "#AAAAAA" // e.g. for PI Setup TabView

        property color dropIndicator: "#505050"
        property color dragBackground: "#C9E1EF"
        property color dragitemOutline: highlightBlue

        property color outgray: darkBackground

        property color radioButton: "#8C8C8C"
        property color radioButtonPressed: "#222222"
    }

    property QtObject margins: QtObject {

        property QtObject mainWindow: QtObject {
            property int top: 32
            property int bottom: 32
            property int left: 20
            property int right: 20
        }

        property QtObject datatype: QtObject {
            property int top: 20
            property int inner: Style.margins.content.inner
            property int left: 20
            property int right: 20

        }

        property QtObject configuration: QtObject {
            property int inner: 12
        }

        property int tooltip: 5

        property QtObject content: QtObject {
            property int inner: 8

            property int left: 14
            property int right: 14
            property int top: 16
            property int bottom: 16
        }

        property QtObject listItem: QtObject {
            property int inner: Style.margins.content.inner
        }

        property QtObject messageDialog: QtObject {
            property int inner: 12
            property int outer: 28
        }
    }

    property QtObject scrollbar: QtObject {
        property int width: 8

        property Item backgroundRect: Rectangle { color: "transparent" }
    }

    property QtObject images: QtObject {
        property int defaultHeight: 16
        property int defaultWidth: 16
    }

    property QtObject radii: QtObject {
        property int emptyRadius: 5
    }


    property QtObject labels: QtObject {

        property QtObject regularLabel: QtObject {
            property int fontSize: 12
            property bool bold: false

            property color color: "black"
        }

        property QtObject regularLabelHighlight: QtObject {
            property int fontSize: 12
            property bool bold: false

            property color color: "white"
        }

        property QtObject regularLabelBold: QtObject {
            property int fontSize: 12
            property bool bold: true

            property color color: "black"
        }

        property QtObject regularLabelBoldHighlight: QtObject {
            property int fontSize: 12
            property bool bold: true

            property color color: "white"
        }


        // the index inside recipe list

        property QtObject recipeIndex: QtObject {
            property int fontSize: 14
            property bool bold: true
        }

        property QtObject selectedRecipeIndex: QtObject {
            property int fontSize: 14
            property bool bold: true
            property color color: "#FFFFFF"
            property int width: 30

        }

    }

    property QtObject rectangularShape: QtObject {
        property int radius: 10

        property int strokeWidth: 2
        property color strokeColor: Style.colors.borderGray

        property bool dashed: true
        property var dashPattern: [6,2]
    }

    property QtObject errorBox: QtObject {
        property int innerMargin: 8
        property color errorBackgroundColor: "#d30000"
        property color warningBackgroundColor: "#CECDCD"

        property QtObject errorLabel: QtObject {
            property int fontSize: 12
            property bool bold: true
            property color color: "#f6f6f6"
        }

        property QtObject warningLabel: QtObject {
            property int fontSize: 12
            property bool bold: false
            property color color: "#505050"
        }
    }

    property QtObject headerWithLine: QtObject {
        property color fontColor: Style.colors.highlightBlue
        property color lineColor: "#D2D2D2"

        property int innerMargin: 8

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: true
        }
    }

    property QtObject expandableContentHeader: QtObject {
        property color borderColor: "#000000"
        property int innerMargin: 8

        property QtObject label: QtObject {
            property int fontSize: 16
            property bool bold: false
        }
    }

    property QtObject detailsHeader: QtObject {
        property color backgroundColor: "#8A8A8A"

        property int leftMargin: 14
        property int innerMargin: 8

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: true

            property color color: "#ffffff"
        }
    }

    property QtObject iconButton: QtObject {
        property color backgroundColor: Style.colors.background
        property color borderColor: "#000000"
        property color readOnlyColor: "#AAAAAA"

        property int borderWidth: 0

        property int spacing: 4

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: false
        }
    }

    property QtObject regularButton: QtObject {

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: false
        }
    }

    property QtObject placeholderRect: QtObject {

        property int spacing: 8
        property int margin: 30

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: false

            property color color: "#505050"
        }
    }

    property QtObject textSwitch: QtObject {

        property int sliderWidth: 24
        property int sliderHeight: 6

        property int spacing: 8

        property QtObject background: QtObject {
            property color checkedColor: Style.colors.highlightBlue
            property color uncheckedColor: "#9C9C9C"
            property color disabledColor:  "#9C9C9C"

            property int radius: 13
        }

        property QtObject circle: QtObject {
            property color enabledColor: "#0078D7"
            property color disabledColor: "#D6D6D6"

            property int diameter: 12
        }

        property QtObject label: QtObject {
            property int fontSize: 12
            property bool bold: false

            property color enabledColor: "black"
            property color disabledColor: "#9C9C9C"
        }
    }

    property QtObject comboBox : QtObject {

        property QtObject label: QtObject {
            property int fontSize: 12
            property color fontColor: "black"
            property bool bold: false
        }

        property color borderColor: "black"
        property color backgroundColor: "white"
        property color disabledColor: Style.colors.outgray

        property color selectedBackgroundColor: Style.colors.highlightBlue
        property color hoverBackgroundColor: Style.colors.hoverBlue
        property color hoverBorderColor: Style.colors.hoverBorder

    }

    property QtObject radioButton: QtObject {

        property font labelFont: Qt.font({
            pixelSize: 14,
            weight: Font.DemiBold
        })

        property int diameter: 18
    }

    property QtObject checkBox: QtObject {

        property font labelFont: Qt.font({
            pixelSize: 14
        })

        property int size: 18
    }

    property QtObject signalPinTable: QtObject {
        property color fontColor: Style.colors.highlightBlue
        property color inactiveEntriesColor: "#D2D2D2"
        property color activeEntriesColor: "#505050"

        property int fontSize: 12
        property int lineHeight: 1
        property int leftMargin: 30

    }

    property QtObject messageDialog: QtObject {
        property int fontSize: 12

        property color background: '#FFFFFF'
        property color borderColor: '#0078D7'
        property color buttonBoxBackground: '#EEEEEE'

        property QtObject titleBar: QtObject {
            property color background: '#505050'

            // Colors picked from Windows's titlebar button:
            property color closeButtonBackgroundHovered: '#E81123'
            property color closeButtonBackgroundPressed: '#A22330'
        }
    }

    property QtObject skeleton: QtObject {
        property color background: '#E8E6E6'
        property int buttonBoxHeight: 48
        property int borderWidth: 1
    }
}
